[][src]Struct gdnative_bindings::ResourceFormatPKM

pub struct ResourceFormatPKM { /* fields omitted */ }

core class ResourceFormatPKM inherits ResourceFormatLoader (reference counted).

Official documentation

See the documentation of this class in the Godot engine's official documentation.

Memory management

The lifetime of this object is automatically managed through reference counting.

Class hierarchy

ResourceFormatPKM inherits methods from:

Methods

impl ResourceFormatPKM[src]

pub fn new_ref(&self) -> Self[src]

Creates a new reference to the same reference-counted object.

pub fn to_resource_format_loader(&self) -> ResourceFormatLoader[src]

Up-cast.

pub fn to_reference(&self) -> Reference[src]

Up-cast.

pub fn to_object(&self) -> Object[src]

Up-cast.

pub fn cast<T: GodotObject>(&self) -> Option<T>[src]

Generic dynamic cast.

Methods from Deref<Target = ResourceFormatLoader>

pub fn new_ref(&self) -> Self[src]

Creates a new reference to the same reference-counted object.

pub fn get_dependencies(&mut self, path: GodotString, add_types: GodotString)[src]

pub fn get_recognized_extensions(&mut self) -> StringArray[src]

pub fn get_resource_type(&mut self, path: GodotString) -> GodotString[src]

pub fn handles_type(&mut self, typename: GodotString) -> bool[src]

pub fn load(&mut self, path: GodotString, original_path: GodotString) -> Variant[src]

pub fn rename_dependencies(
    &mut self,
    path: GodotString,
    renames: GodotString
) -> i64
[src]

pub fn init_ref(&mut self) -> bool[src]

Inherited from Reference.

pub fn to_reference(&self) -> Reference[src]

Up-cast.

pub fn to_object(&self) -> Object[src]

Up-cast.

pub fn cast<T: GodotObject>(&self) -> Option<T>[src]

Generic dynamic cast.