[−][src]Struct gdnative_bindings::VisualShaderNodeGroupBase
core class VisualShaderNodeGroupBase inherits VisualShaderNode (reference counted).
Official documentation
See the documentation of this class in the Godot engine's official documentation.
Memory management
The lifetime of this object is automatically managed through reference counting.
Class hierarchy
VisualShaderNodeGroupBase inherits methods from:
Methods
impl VisualShaderNodeGroupBase[src]
pub fn new() -> Self[src]
pub fn new_ref(&self) -> Self[src]
Creates a new reference to the same reference-counted object.
pub fn add_input_port(&mut self, id: i64, _type: i64, name: GodotString)[src]
pub fn add_output_port(&mut self, id: i64, _type: i64, name: GodotString)[src]
pub fn clear_input_ports(&mut self)[src]
pub fn clear_output_ports(&mut self)[src]
pub fn get_free_input_port_id(&self) -> i64[src]
pub fn get_free_output_port_id(&self) -> i64[src]
pub fn get_input_port_count(&self) -> i64[src]
pub fn get_inputs(&self) -> GodotString[src]
pub fn get_output_port_count(&self) -> i64[src]
pub fn get_outputs(&self) -> GodotString[src]
pub fn get_size(&self) -> Vector2[src]
pub fn has_input_port(&self, id: i64) -> bool[src]
pub fn has_output_port(&self, id: i64) -> bool[src]
pub fn is_valid_port_name(&self, name: GodotString) -> bool[src]
pub fn remove_input_port(&mut self, id: i64)[src]
pub fn remove_output_port(&mut self, id: i64)[src]
pub fn set_input_port_name(&mut self, id: i64, name: GodotString)[src]
pub fn set_input_port_type(&mut self, id: i64, _type: i64)[src]
pub fn set_inputs(&mut self, inputs: GodotString)[src]
pub fn set_output_port_name(&mut self, id: i64, name: GodotString)[src]
pub fn set_output_port_type(&mut self, id: i64, _type: i64)[src]
pub fn set_outputs(&mut self, outputs: GodotString)[src]
pub fn set_size(&mut self, size: Vector2)[src]
pub fn to_visual_shader_node(&self) -> VisualShaderNode[src]
Up-cast.
pub fn to_resource(&self) -> Resource[src]
Up-cast.
pub fn to_reference(&self) -> Reference[src]
Up-cast.
pub fn to_object(&self) -> Object[src]
Up-cast.
pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
Generic dynamic cast.
Methods from Deref<Target = VisualShaderNode>
pub const PORT_TYPE_VECTOR: i64[src]
pub const PORT_TYPE_SAMPLER: i64[src]
pub const PORT_TYPE_BOOLEAN: i64[src]
pub const PORT_TYPE_SCALAR: i64[src]
pub const PORT_TYPE_MAX: i64[src]
pub const PORT_TYPE_TRANSFORM: i64[src]
pub fn new_ref(&self) -> Self[src]
Creates a new reference to the same reference-counted object.
pub fn get_default_input_values(&self) -> VariantArray[src]
pub fn get_input_port_default_value(&self, port: i64) -> Variant[src]
pub fn get_output_port_for_preview(&self) -> i64[src]
pub fn set_default_input_values(&mut self, values: VariantArray)[src]
pub fn set_input_port_default_value(&mut self, port: i64, value: Variant)[src]
pub fn set_output_port_for_preview(&mut self, port: i64)[src]
pub fn to_resource(&self) -> Resource[src]
Up-cast.
pub fn to_reference(&self) -> Reference[src]
Up-cast.
pub fn to_object(&self) -> Object[src]
Up-cast.
pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
Generic dynamic cast.