Module utils

Module utils 

Utility functions and extension traits that depend on generated bindings

Traits

NodeResolveExt

Functions

autoload
Convenience method to obtain a reference to an “auto-load” node, that is a child of the root node.