Module utils
gdnative_
bindings
0.11.3
Module utils
Module Items
Traits
Functions
In crate gdnative_
bindings
gdnative_bindings
Module
utils
Utility functions and extension traits that depend on generated bindings
Traits

Node
Resolve
Ext
Functions

autoload
⚠
Convenience method to obtain a reference to an “auto-load” node, that is a child of the root node.